###################
### Goobler 2022 ##
###################
# Scripts made by Eric #

from ..Core.init import Init

Init()